# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/image.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from is_msgs import common_pb2 as is__msgs_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/image.proto',
  package='is.vision',
  syntax='proto3',
  serialized_pb=_b('\n\x13is_msgs/image.proto\x12\tis.vision\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14is_msgs/common.proto\"1\n\x05Image\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\t\n\x07\x63ontent\"h\n\x0bImageFormat\x12\'\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x17.is.vision.ImageFormats\x12\x30\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\"3\n\x0c\x42oundingPoly\x12#\n\x08vertices\x18\x01 \x03(\x0b\x32\x11.is.vision.Vertex\"+\n\nResolution\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\r\"3\n\nColorSpace\x12%\n\x05value\x18\x01 \x01(\x0e\x32\x16.is.vision.ColorSpaces\"\xb7\x01\n\rImageSettings\x12)\n\nresolution\x18\x01 \x01(\x0b\x32\x15.is.vision.Resolution\x12&\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\x16.is.vision.ImageFormat\x12*\n\x0b\x63olor_space\x18\x03 \x01(\x0b\x32\x15.is.vision.ColorSpace\x12\'\n\x06region\x18\x04 \x01(\x0b\x32\x17.is.vision.BoundingPoly\"w\n\x0fImageAnnotation\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12\'\n\x06region\x18\x03 \x01(\x0b\x32\x17.is.vision.BoundingPoly\x12\x1d\n\x04pose\x18\x04 \x01(\x0b\x32\x0f.is.common.Pose\"C\n\x10ImageAnnotations\x12/\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x1a.is.vision.ImageAnnotation*+\n\x0cImageFormats\x12\x07\n\x03PNG\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x08\n\x04WebP\x10\x02*4\n\x0b\x43olorSpaces\x12\x07\n\x03RGB\x10\x00\x12\x08\n\x04GRAY\x10\x01\x12\t\n\x05YCbCr\x10\x02\x12\x07\n\x03HSV\x10\x03\x42\x11\n\rcom.is.visionP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,is__msgs_dot_common__pb2.DESCRIPTOR,])

_IMAGEFORMATS = _descriptor.EnumDescriptor(
  name='ImageFormats',
  full_name='is.vision.ImageFormats',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PNG', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPEG', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WebP', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=804,
  serialized_end=847,
)
_sym_db.RegisterEnumDescriptor(_IMAGEFORMATS)

ImageFormats = enum_type_wrapper.EnumTypeWrapper(_IMAGEFORMATS)
_COLORSPACES = _descriptor.EnumDescriptor(
  name='ColorSpaces',
  full_name='is.vision.ColorSpaces',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RGB', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GRAY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YCbCr', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HSV', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=849,
  serialized_end=901,
)
_sym_db.RegisterEnumDescriptor(_COLORSPACES)

ColorSpaces = enum_type_wrapper.EnumTypeWrapper(_COLORSPACES)
PNG = 0
JPEG = 1
WebP = 2
RGB = 0
GRAY = 1
YCbCr = 2
HSV = 3



_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='is.vision.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='is.vision.Image.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='is.vision.Image.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='is.vision.Image.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=88,
  serialized_end=137,
)


_IMAGEFORMAT = _descriptor.Descriptor(
  name='ImageFormat',
  full_name='is.vision.ImageFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='is.vision.ImageFormat.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression', full_name='is.vision.ImageFormat.compression', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=243,
)


_VERTEX = _descriptor.Descriptor(
  name='Vertex',
  full_name='is.vision.Vertex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='is.vision.Vertex.x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='is.vision.Vertex.y', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=275,
)


_BOUNDINGPOLY = _descriptor.Descriptor(
  name='BoundingPoly',
  full_name='is.vision.BoundingPoly',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='is.vision.BoundingPoly.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=328,
)


_RESOLUTION = _descriptor.Descriptor(
  name='Resolution',
  full_name='is.vision.Resolution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='is.vision.Resolution.height', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='is.vision.Resolution.width', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=373,
)


_COLORSPACE = _descriptor.Descriptor(
  name='ColorSpace',
  full_name='is.vision.ColorSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='is.vision.ColorSpace.value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=426,
)


_IMAGESETTINGS = _descriptor.Descriptor(
  name='ImageSettings',
  full_name='is.vision.ImageSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolution', full_name='is.vision.ImageSettings.resolution', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='is.vision.ImageSettings.format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color_space', full_name='is.vision.ImageSettings.color_space', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='is.vision.ImageSettings.region', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=612,
)


_IMAGEANNOTATION = _descriptor.Descriptor(
  name='ImageAnnotation',
  full_name='is.vision.ImageAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='is.vision.ImageAnnotation.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='is.vision.ImageAnnotation.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='is.vision.ImageAnnotation.region', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pose', full_name='is.vision.ImageAnnotation.pose', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=733,
)


_IMAGEANNOTATIONS = _descriptor.Descriptor(
  name='ImageAnnotations',
  full_name='is.vision.ImageAnnotations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='annotations', full_name='is.vision.ImageAnnotations.annotations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=802,
)

_IMAGE.oneofs_by_name['content'].fields.append(
  _IMAGE.fields_by_name['data'])
_IMAGE.fields_by_name['data'].containing_oneof = _IMAGE.oneofs_by_name['content']
_IMAGE.oneofs_by_name['content'].fields.append(
  _IMAGE.fields_by_name['uri'])
_IMAGE.fields_by_name['uri'].containing_oneof = _IMAGE.oneofs_by_name['content']
_IMAGEFORMAT.fields_by_name['format'].enum_type = _IMAGEFORMATS
_IMAGEFORMAT.fields_by_name['compression'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_BOUNDINGPOLY.fields_by_name['vertices'].message_type = _VERTEX
_COLORSPACE.fields_by_name['value'].enum_type = _COLORSPACES
_IMAGESETTINGS.fields_by_name['resolution'].message_type = _RESOLUTION
_IMAGESETTINGS.fields_by_name['format'].message_type = _IMAGEFORMAT
_IMAGESETTINGS.fields_by_name['color_space'].message_type = _COLORSPACE
_IMAGESETTINGS.fields_by_name['region'].message_type = _BOUNDINGPOLY
_IMAGEANNOTATION.fields_by_name['region'].message_type = _BOUNDINGPOLY
_IMAGEANNOTATION.fields_by_name['pose'].message_type = is__msgs_dot_common__pb2._POSE
_IMAGEANNOTATIONS.fields_by_name['annotations'].message_type = _IMAGEANNOTATION
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['ImageFormat'] = _IMAGEFORMAT
DESCRIPTOR.message_types_by_name['Vertex'] = _VERTEX
DESCRIPTOR.message_types_by_name['BoundingPoly'] = _BOUNDINGPOLY
DESCRIPTOR.message_types_by_name['Resolution'] = _RESOLUTION
DESCRIPTOR.message_types_by_name['ColorSpace'] = _COLORSPACE
DESCRIPTOR.message_types_by_name['ImageSettings'] = _IMAGESETTINGS
DESCRIPTOR.message_types_by_name['ImageAnnotation'] = _IMAGEANNOTATION
DESCRIPTOR.message_types_by_name['ImageAnnotations'] = _IMAGEANNOTATIONS
DESCRIPTOR.enum_types_by_name['ImageFormats'] = _IMAGEFORMATS
DESCRIPTOR.enum_types_by_name['ColorSpaces'] = _COLORSPACES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), dict(
  DESCRIPTOR = _IMAGE,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.Image)
  ))
_sym_db.RegisterMessage(Image)

ImageFormat = _reflection.GeneratedProtocolMessageType('ImageFormat', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEFORMAT,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageFormat)
  ))
_sym_db.RegisterMessage(ImageFormat)

Vertex = _reflection.GeneratedProtocolMessageType('Vertex', (_message.Message,), dict(
  DESCRIPTOR = _VERTEX,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.Vertex)
  ))
_sym_db.RegisterMessage(Vertex)

BoundingPoly = _reflection.GeneratedProtocolMessageType('BoundingPoly', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGPOLY,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.BoundingPoly)
  ))
_sym_db.RegisterMessage(BoundingPoly)

Resolution = _reflection.GeneratedProtocolMessageType('Resolution', (_message.Message,), dict(
  DESCRIPTOR = _RESOLUTION,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.Resolution)
  ))
_sym_db.RegisterMessage(Resolution)

ColorSpace = _reflection.GeneratedProtocolMessageType('ColorSpace', (_message.Message,), dict(
  DESCRIPTOR = _COLORSPACE,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ColorSpace)
  ))
_sym_db.RegisterMessage(ColorSpace)

ImageSettings = _reflection.GeneratedProtocolMessageType('ImageSettings', (_message.Message,), dict(
  DESCRIPTOR = _IMAGESETTINGS,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageSettings)
  ))
_sym_db.RegisterMessage(ImageSettings)

ImageAnnotation = _reflection.GeneratedProtocolMessageType('ImageAnnotation', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEANNOTATION,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageAnnotation)
  ))
_sym_db.RegisterMessage(ImageAnnotation)

ImageAnnotations = _reflection.GeneratedProtocolMessageType('ImageAnnotations', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEANNOTATIONS,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageAnnotations)
  ))
_sym_db.RegisterMessage(ImageAnnotations)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\rcom.is.visionP\001'))
# @@protoc_insertion_point(module_scope)
