# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/tests.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/tests.proto',
  package='is.tests',
  syntax='proto3',
  serialized_pb=_b('\n\x13is_msgs/tests.proto\x12\x08is.tests\x1a\x16is_msgs/validate.proto\"s\n\x03\x46oo\x12$\n\x05myint\x18\x01 \x01(\x05\x42\x15\xba\xe9\xc0\x03\x10\x1a\x0e\x18\xd0\x0f(\xce\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\"\n\x07myfloat\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x15\x9a\x99\x99>%\xcd\xcc\xcc=\x12\"\n\x08mydouble\x18\x03 \x01(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t\x19\xb4\xc8v\xbe\x9f\xaa@@\"B\n\x03\x42\x61r\x12\x1c\n\x05myfoo\x18\x01 \x01(\x0b\x32\r.is.tests.Foo\x12\x1d\n\x07myfloat\x18\x02 \x01(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05%\x00\x00\x80\xbf\"\x87\x02\n\x07Repeats\x12\x1b\n\x04\x66oos\x18\x01 \x03(\x0b\x32\r.is.tests.Foo\x12\'\n\x04\x66oo2\x18\x02 \x01(\x0b\x32\r.is.tests.FooB\n\xba\xe9\xc0\x03\x05\x8a\x01\x02\x10\x01\x12\"\n\x06int32s\x18\x03 \x03(\x05\x42\x12\xba\xe9\xc0\x03\r\x1a\x0b\x10\xf6\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\x07uint32s\x18\x04 \x03(\rB\t\xba\xe9\xc0\x03\x04*\x02 \n\x12\x1c\n\x06\x66loats\x18\x05 \x03(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05\x1d\x00\x00 \xc1\x12!\n\x07\x64oubles\x18\x06 \x03(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t)\x00\x00\x00\x00\x00\x00$\xc0\x12\x19\n\x06int64s\x18\x07 \x03(\x03\x42\t\xba\xe9\xc0\x03\x04\"\x02\x10\n\x12\x1a\n\x07uint64s\x18\x08 \x03(\x04\x42\t\xba\xe9\xc0\x03\x04\x32\x02 db\x06proto3')
  ,
  dependencies=[is__msgs_dot_validate__pb2.DESCRIPTOR,])




_FOO = _descriptor.Descriptor(
  name='Foo',
  full_name='is.tests.Foo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='myint', full_name='is.tests.Foo.myint', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\020\032\016\030\320\017(\316\377\377\377\377\377\377\377\377\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='myfloat', full_name='is.tests.Foo.myfloat', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\014\n\n\025\232\231\231>%\315\314\314=')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mydouble', full_name='is.tests.Foo.mydouble', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t\031\264\310v\276\237\252@@')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=172,
)


_BAR = _descriptor.Descriptor(
  name='Bar',
  full_name='is.tests.Bar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='myfoo', full_name='is.tests.Bar.myfoo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='myfloat', full_name='is.tests.Bar.myfloat', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005%\000\000\200\277')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=240,
)


_REPEATS = _descriptor.Descriptor(
  name='Repeats',
  full_name='is.tests.Repeats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='foos', full_name='is.tests.Repeats.foos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='foo2', full_name='is.tests.Repeats.foo2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\005\212\001\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int32s', full_name='is.tests.Repeats.int32s', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\r\032\013\020\366\377\377\377\377\377\377\377\377\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32s', full_name='is.tests.Repeats.uint32s', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004*\002 \n')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floats', full_name='is.tests.Repeats.floats', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005\035\000\000 \301')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubles', full_name='is.tests.Repeats.doubles', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t)\000\000\000\000\000\000$\300')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64s', full_name='is.tests.Repeats.int64s', index=6,
      number=7, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004\"\002\020\n')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64s', full_name='is.tests.Repeats.uint64s', index=7,
      number=8, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\0042\002 d')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=506,
)

_BAR.fields_by_name['myfoo'].message_type = _FOO
_REPEATS.fields_by_name['foos'].message_type = _FOO
_REPEATS.fields_by_name['foo2'].message_type = _FOO
DESCRIPTOR.message_types_by_name['Foo'] = _FOO
DESCRIPTOR.message_types_by_name['Bar'] = _BAR
DESCRIPTOR.message_types_by_name['Repeats'] = _REPEATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Foo = _reflection.GeneratedProtocolMessageType('Foo', (_message.Message,), dict(
  DESCRIPTOR = _FOO,
  __module__ = 'is_msgs.tests_pb2'
  # @@protoc_insertion_point(class_scope:is.tests.Foo)
  ))
_sym_db.RegisterMessage(Foo)

Bar = _reflection.GeneratedProtocolMessageType('Bar', (_message.Message,), dict(
  DESCRIPTOR = _BAR,
  __module__ = 'is_msgs.tests_pb2'
  # @@protoc_insertion_point(class_scope:is.tests.Bar)
  ))
_sym_db.RegisterMessage(Bar)

Repeats = _reflection.GeneratedProtocolMessageType('Repeats', (_message.Message,), dict(
  DESCRIPTOR = _REPEATS,
  __module__ = 'is_msgs.tests_pb2'
  # @@protoc_insertion_point(class_scope:is.tests.Repeats)
  ))
_sym_db.RegisterMessage(Repeats)


_FOO.fields_by_name['myint'].has_options = True
_FOO.fields_by_name['myint']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\020\032\016\030\320\017(\316\377\377\377\377\377\377\377\377\001'))
_FOO.fields_by_name['myfloat'].has_options = True
_FOO.fields_by_name['myfloat']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\014\n\n\025\232\231\231>%\315\314\314='))
_FOO.fields_by_name['mydouble'].has_options = True
_FOO.fields_by_name['mydouble']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t\031\264\310v\276\237\252@@'))
_BAR.fields_by_name['myfloat'].has_options = True
_BAR.fields_by_name['myfloat']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005%\000\000\200\277'))
_REPEATS.fields_by_name['foo2'].has_options = True
_REPEATS.fields_by_name['foo2']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\005\212\001\002\020\001'))
_REPEATS.fields_by_name['int32s'].has_options = True
_REPEATS.fields_by_name['int32s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\r\032\013\020\366\377\377\377\377\377\377\377\377\001'))
_REPEATS.fields_by_name['uint32s'].has_options = True
_REPEATS.fields_by_name['uint32s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004*\002 \n'))
_REPEATS.fields_by_name['floats'].has_options = True
_REPEATS.fields_by_name['floats']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005\035\000\000 \301'))
_REPEATS.fields_by_name['doubles'].has_options = True
_REPEATS.fields_by_name['doubles']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t)\000\000\000\000\000\000$\300'))
_REPEATS.fields_by_name['int64s'].has_options = True
_REPEATS.fields_by_name['int64s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004\"\002\020\n'))
_REPEATS.fields_by_name['uint64s'].has_options = True
_REPEATS.fields_by_name['uint64s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\0042\002 d'))
# @@protoc_insertion_point(module_scope)
