# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/power.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/power.proto',
  package='is.common',
  syntax='proto3',
  serialized_pb=_b('\n\x13is_msgs/power.proto\x12\tis.common\x1a\x1egoogle/protobuf/duration.proto\"\xbc\x03\n\tPowerInfo\x12\x0f\n\x07voltage\x18\x01 \x01(\x02\x12\x18\n\x10terminal_voltage\x18\x02 \x01(\x02\x12\x14\n\x0c\x63\x65ll_voltage\x18\x03 \x03(\x02\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x02\x12\x10\n\x08\x63\x61pacity\x18\x05 \x01(\x02\x12.\n\x04type\x18\x06 \x01(\x0e\x32 .is.common.PowerInfo.BatteryType\x12\x32\n\x06status\x18\x07 \x01(\x0e\x32\".is.common.PowerInfo.BatteryStatus\x12)\n\x06uptime\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x61utonomy\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\"3\n\x0b\x42\x61tteryType\x12\x06\n\x02PB\x10\x00\x12\x08\n\x04NICD\x10\x01\x12\x08\n\x04NIMH\x10\x02\x12\x08\n\x04LIPO\x10\x03\"[\n\rBatteryStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x43HARGING\x10\x01\x12\x0f\n\x0b\x44ISCHARGING\x10\x02\x12\x0b\n\x07\x43HARGED\x10\x03\x12\x11\n\rNOT_CONNECTED\x10\x04\x42\x11\n\rcom.is.commonP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])



_POWERINFO_BATTERYTYPE = _descriptor.EnumDescriptor(
  name='BatteryType',
  full_name='is.common.PowerInfo.BatteryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PB', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NICD', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NIMH', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIPO', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=367,
  serialized_end=418,
)
_sym_db.RegisterEnumDescriptor(_POWERINFO_BATTERYTYPE)

_POWERINFO_BATTERYSTATUS = _descriptor.EnumDescriptor(
  name='BatteryStatus',
  full_name='is.common.PowerInfo.BatteryStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARGING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCHARGING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARGED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_CONNECTED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=420,
  serialized_end=511,
)
_sym_db.RegisterEnumDescriptor(_POWERINFO_BATTERYSTATUS)


_POWERINFO = _descriptor.Descriptor(
  name='PowerInfo',
  full_name='is.common.PowerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voltage', full_name='is.common.PowerInfo.voltage', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='terminal_voltage', full_name='is.common.PowerInfo.terminal_voltage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_voltage', full_name='is.common.PowerInfo.cell_voltage', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='is.common.PowerInfo.charge', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capacity', full_name='is.common.PowerInfo.capacity', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='is.common.PowerInfo.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='is.common.PowerInfo.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uptime', full_name='is.common.PowerInfo.uptime', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='autonomy', full_name='is.common.PowerInfo.autonomy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POWERINFO_BATTERYTYPE,
    _POWERINFO_BATTERYSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=511,
)

_POWERINFO.fields_by_name['type'].enum_type = _POWERINFO_BATTERYTYPE
_POWERINFO.fields_by_name['status'].enum_type = _POWERINFO_BATTERYSTATUS
_POWERINFO.fields_by_name['uptime'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_POWERINFO.fields_by_name['autonomy'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_POWERINFO_BATTERYTYPE.containing_type = _POWERINFO
_POWERINFO_BATTERYSTATUS.containing_type = _POWERINFO
DESCRIPTOR.message_types_by_name['PowerInfo'] = _POWERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PowerInfo = _reflection.GeneratedProtocolMessageType('PowerInfo', (_message.Message,), dict(
  DESCRIPTOR = _POWERINFO,
  __module__ = 'is_msgs.power_pb2'
  # @@protoc_insertion_point(class_scope:is.common.PowerInfo)
  ))
_sym_db.RegisterMessage(PowerInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\rcom.is.commonP\001'))
# @@protoc_insertion_point(module_scope)
