# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/wire.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/wire.proto',
  package='is.wire',
  syntax='proto3',
  serialized_pb=_b('\n\x12is_msgs/wire.proto\x12\x07is.wire\x1a\x19google/protobuf/any.proto\"8\n\x06Status\x12!\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x13.is.wire.StatusCode\x12\x0b\n\x03why\x18\x02 \x01(\t\"\xeb\x01\n\nWireFormat\x12\r\n\x03raw\x18\x01 \x01(\x0cH\x00\x12\'\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x12\n\ncreated_at\x18\x03 \x01(\x04\x12*\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32\x14.is.wire.ContentType\x12\x1f\n\x06status\x18\x05 \x01(\x0b\x32\x0f.is.wire.Status\x12\x16\n\x0e\x63orrelation_id\x18\x06 \x01(\x04\x12\x10\n\x08reply_to\x18\x07 \x01(\t\x12\x12\n\nexpires_in\x18\x08 \x01(\rB\x06\n\x04\x62ody*\xfe\x01\n\nStatusCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x13\n\x0fUNAUTHENTICATED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x10\n\x0cOUT_OF_RANGE\x10\n\x12\x11\n\rUNIMPLEMENTED\x10\x0b\x12\x12\n\x0eINTERNAL_ERROR\x10\x0c*>\n\x0b\x43ontentType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08PROTOBUF\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\r\n\tPROTOTEXT\x10\x03\x42\x0f\n\x0b\x63om.is.wireP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='is.wire.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEADLINE_EXCEEDED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAUTHENTICATED', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_PRECONDITION', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_RANGE', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIMPLEMENTED', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=12, number=12,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=355,
  serialized_end=609,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='is.wire.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOBUF', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOTEXT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=611,
  serialized_end=673,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNKNOWN = 0
OK = 1
CANCELLED = 2
INVALID_ARGUMENT = 3
DEADLINE_EXCEEDED = 4
NOT_FOUND = 5
ALREADY_EXISTS = 6
PERMISSION_DENIED = 7
UNAUTHENTICATED = 8
FAILED_PRECONDITION = 9
OUT_OF_RANGE = 10
UNIMPLEMENTED = 11
INTERNAL_ERROR = 12
NONE = 0
PROTOBUF = 1
JSON = 2
PROTOTEXT = 3



_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='is.wire.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='is.wire.Status.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='why', full_name='is.wire.Status.why', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=114,
)


_WIREFORMAT = _descriptor.Descriptor(
  name='WireFormat',
  full_name='is.wire.WireFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='is.wire.WireFormat.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='is.wire.WireFormat.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='is.wire.WireFormat.created_at', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='is.wire.WireFormat.content_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='is.wire.WireFormat.status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='correlation_id', full_name='is.wire.WireFormat.correlation_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='is.wire.WireFormat.reply_to', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='is.wire.WireFormat.expires_in', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='is.wire.WireFormat.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=117,
  serialized_end=352,
)

_STATUS.fields_by_name['code'].enum_type = _STATUSCODE
_WIREFORMAT.fields_by_name['message'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_WIREFORMAT.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_WIREFORMAT.fields_by_name['status'].message_type = _STATUS
_WIREFORMAT.oneofs_by_name['body'].fields.append(
  _WIREFORMAT.fields_by_name['raw'])
_WIREFORMAT.fields_by_name['raw'].containing_oneof = _WIREFORMAT.oneofs_by_name['body']
_WIREFORMAT.oneofs_by_name['body'].fields.append(
  _WIREFORMAT.fields_by_name['message'])
_WIREFORMAT.fields_by_name['message'].containing_oneof = _WIREFORMAT.oneofs_by_name['body']
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['WireFormat'] = _WIREFORMAT
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
DESCRIPTOR.enum_types_by_name['ContentType'] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
  DESCRIPTOR = _STATUS,
  __module__ = 'is_msgs.wire_pb2'
  # @@protoc_insertion_point(class_scope:is.wire.Status)
  ))
_sym_db.RegisterMessage(Status)

WireFormat = _reflection.GeneratedProtocolMessageType('WireFormat', (_message.Message,), dict(
  DESCRIPTOR = _WIREFORMAT,
  __module__ = 'is_msgs.wire_pb2'
  # @@protoc_insertion_point(class_scope:is.wire.WireFormat)
  ))
_sym_db.RegisterMessage(WireFormat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\013com.is.wireP\001'))
# @@protoc_insertion_point(module_scope)
